@@ -78,15 +78,18 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
             },
             timeout=timeout,
         ) as response:
-            logger.info(
+            logger.debug(
                 f'mark notification as read done, status: {response.status}'
             )
 
             answer = await response.json()
+            logger.debug(
+                f'mark notification as read answer: {answer}'
+            )
             done = answer.get('done', False)
             result = answer.get('result', False)
             error = answer.get('error', None)
             if not done:
-                logger.debug(f'mark notification as read failed, error: {error}')
+                logger.error(f'mark notification as read failed, error: {error}')
                 raise NotificationsServerError(f'mark notification as read failed, error: {error}')
             return result
